@@ -5,7 +5,7 @@ gi.require_version("Adw", "1")
 from gi.repository import Adw, Gdk, Gio, GLib, GObject, Gtk
 
 import logging
-from typing import Callable, List, Optional
+from typing import Callable, Optional
 
 from iotas.backup_manager import BackupManager
 import iotas.const as const
@@ -81,10 +81,10 @@ class Application(Adw.Application):
         iotas.config_manager.set_nextcloud_username("")
         self.__window.close()
 
-    def do_open(self, files: List[Gio.File], n_files: int, _hint: str) -> None:
+    def do_open(self, files: list[Gio.File], n_files: int, _hint: str) -> None:
         """Handle opening "files". In this case URI for the temporary handler.
 
-        :param List[Gio.File] files: Files
+        :param list[Gio.File] files: Files
         :param int n_files: Number of files
         :param str _hint: Hint
         """
