@@ -5,7 +5,7 @@ import logging
 import os
 import sqlite3
 from threading import Lock
-from typing import List, Optional
+from typing import Optional
 
 import iotas.config_manager
 
@@ -138,6 +138,7 @@ class Database:
                     sql.execute("PRAGMA user_version=%s" % self.VERSION)
             except Exception as e:
                 logging.error("DB init error: {}".format(e))
+                raise (e)
         else:
             current_version = self.__get_version()
             if current_version < self.VERSION:
@@ -152,12 +153,12 @@ class Database:
     def release_lock(self):
         self.__thread_lock.release()
 
-    def execute(self, request: str) -> List:
+    def execute(self, request: str) -> list:
         """Execute a query
 
         :param str request: The request
         :return: A list of ids, if applicable
-        :rtype: List
+        :rtype: list
         """
         try:
             ids = []
