@@ -19,6 +19,8 @@ from iotas.export_dialog import ExportDialog
 from iotas.focus_mode_helper import FocusModeHelper
 from iotas.font_size_selector import FontSizeSelector
 from iotas.note import Note
+from iotas.outline_dialog import OutlineDialog
+from iotas.outline_generator import OutlineHeading, OutlineGenerator
 from iotas.text_utils import (
     parse_any_url_at_iter,
     parse_markdown_automatic_link,
@@ -97,9 +99,12 @@ class Editor(Adw.Bin):
         self.__cancel_action = None
         self.__previous_sessions = []
         self.__pointer_cursor_y = None
+        self.__outline_dialog = None
 
         self.__hiding_bars_timeout = None
 
+        self.__outline_generator = OutlineGenerator()
+
         self._menu_button.get_popover().add_child(ThemeSelector(), "theme")
         self.__font_size_selector = FontSizeSelector()
         self._menu_button.get_popover().add_child(self.__font_size_selector, "fontsize")
@@ -335,6 +340,9 @@ class Editor(Adw.Bin):
             GLib.source_remove(self.__hiding_bars_timeout)
             self.__hiding_bars_timeout = None
 
+        if self.__outline_dialog:
+            self.__outline_dialog.close()
+
         if self.current_note.title_is_top_line:
             self.current_note.title_is_top_line = False
 
@@ -578,6 +586,11 @@ class Editor(Adw.Bin):
         action_group.add_action(action)
         app.set_accels_for_action("editor.export-note", ["<Control><Shift>s"])
 
+        action = Gio.SimpleAction.new("show-outline")
+        action.connect("activate", lambda _o, _p: self.__show_outline())
+        action_group.add_action(action)
+        app.set_accels_for_action("editor.show-outline", ["<Control>j"])
+
         action = Gio.SimpleAction.new("delete-note")
         action.connect("activate", lambda _o, _p: self.emit("note-deleted", self.__note))
         action_group.add_action(action)
@@ -1044,6 +1057,10 @@ class Editor(Adw.Bin):
             self.__updating_from_remote = False
             self.set_sensitive(True)
 
+            # Update outline from remote
+            if self.__outline_dialog:
+                self.__show_outline()
+
     def __get_scroll_position(self) -> None:
         adj = self._editor_scrolledwin.get_vadjustment()
         value = adj.get_value()
@@ -1582,3 +1599,40 @@ class Editor(Adw.Bin):
         buffer = self._sourceview.get_buffer()
         cursor_iter = buffer.get_iter_at_offset(session.cursor_position)
         buffer.place_cursor(cursor_iter)
+
+    def __show_outline(self) -> None:
+        if self.__outline_dialog:
+            self.__outline_dialog.close()
+
+        self.__enable_actions(False)
+
+        dialog = OutlineDialog()
+        dialog.present(self)
+
+        def populate(headings: list[OutlineHeading]) -> None:
+            # This makes a crude assumption that if the locale is RTL the document contents are RTL.
+            # Likely better than ignoring RTL but worse than knowing the document direction.
+            rtl = self.get_default_direction() == Gtk.TextDirection.RTL
+            dialog.populate(headings, rtl)
+
+        self.__outline_generator.generate(self.__note, populate)
+
+        def jump_to(dialog: OutlineDialog, line: int) -> None:
+            if self._render_edit_stack.get_visible_child() == self._editor_scrolledwin:
+                buffer = self._sourceview.get_buffer()
+                success, line_iter = buffer.get_iter_at_line(line)
+                buffer.place_cursor(line_iter)
+                self._sourceview.jump_to_insertion_point()
+            else:
+                self.__render_view.scroll_to_heading(line)
+
+        dialog.connect("jump-to", jump_to)
+
+        def outline_closed(dialog: OutlineDialog) -> None:
+            dialog.disconnect_by_func(jump_to)
+            dialog.disconnect_by_func(outline_closed)
+            self.__outline_dialog = None
+            self.__enable_actions(True)
+
+        dialog.connect("closed", outline_closed)
+        self.__outline_dialog = dialog
