@@ -163,6 +163,16 @@ class Exporter(GObject.Object):
             self.__note, searching=False, export_format="html"
         )
 
+        if os.path.exists(self.__location):
+            logging.debug(f"Removing existing {self.__location}")
+            try:
+                shutil.rmtree(self.__location)
+            except OSError as e:
+                self.emit("failed", self.__out_format, e)
+                logging.warning("Failed to replace dir for HTML export: %s", e)
+                self.__active = False
+                return
+
         try:
             os.mkdir(self.__location)
         except OSError as e:
