@@ -4,7 +4,7 @@ from enum import IntEnum, auto
 import logging
 import math
 import re
-from typing import Callable, List, Optional
+from typing import Callable, Optional
 
 from iotas.ordered_list_utils import (
     check_line_for_ordered_list_item,
@@ -910,12 +910,12 @@ class Formatter(GObject.Object):
             self.__insert_space_if_not_exists(line_start)
 
     def __remove_existing_list_marker_on_line(
-        self, insert: Gtk.TextIter, types: List[ListType]
+        self, insert: Gtk.TextIter, types: list[ListType]
     ) -> bool:
         """Remove any existing list marker for provided list types on line.
 
         :param Gtk.TextIter: Iter on line
-        :param List[ListType]: Types to remove
+        :param list[ListType]: Types to remove
         :return: Whether any marker was removed
         :rtype: bool
         """
