@@ -72,6 +72,9 @@ class HtmlGenerator(GObject.Object):
         if self.__config_manager.get_markdown_tex_support():
             md.use(dollarmath_plugin, renderer=self.render_tex)
         parser_tokens = md.parse(note.content)
+        for token in parser_tokens:
+            if token.map:
+                token.attrs["data-map"] = token.map[0]
         content = md.renderer.render(parser_tokens, md.options, None)
 
         if self.__html_template is None:
