@@ -1,6 +1,6 @@
 from gi.repository import GObject, Gio, Gtk
 
-from typing import Any, Callable, Generator, List, NamedTuple, Optional
+from typing import Any, Callable, Generator, NamedTuple, Optional
 
 from iotas.category import Category
 import iotas.config_manager
@@ -256,10 +256,10 @@ class IndexNoteList(Gtk.Box):
             listbox.select_row(previous_row)
             previous_row.grab_focus()
 
-    def restrict_for_search_by_ids(self, ids: Optional[List[int]]) -> None:
+    def restrict_for_search_by_ids(self, ids: Optional[list[int]]) -> None:
         """Restrict by identifiers while searching.
 
-        :param Optional[List[int]] ids: Identifiers
+        :param Optional[list[int]] ids: Identifiers
         """
         if ids and len(ids) > self.__search_base_note_count:
             self.__search_full_set = ids
