@@ -117,6 +117,20 @@ class MarkdownRenderView(WebKit.WebView):
         )
         self.__content_manager.add_style_sheet(self.__user_stylesheet)
 
+    def scroll_to_heading(self, line_number: int) -> None:
+        """Scroll to heading.
+
+        :param int line_number: Line the heading in source markdown
+        """
+        script = f"""
+        element = document.querySelector('[data-map="{line_number}"]');
+        if (element)
+            element.scrollIntoView();
+        """
+        self.evaluate_javascript(
+            script, length=-1, world_name=None, source_uri=None, cancellable=None, callback=None
+        )
+
     @staticmethod
     def on_decide_policy(
         _web_view: WebKit.WebView,
