@@ -2,7 +2,7 @@ from gettext import gettext as _
 import gi
 
 gi.require_version("GtkSource", "5")
-from gi.repository import Adw, Gio, GLib, Gtk, GtkSource
+from gi.repository import Adw, Gio, GLib, GObject, Gtk, GtkSource, Pango
 
 import iotas.config_manager
 from iotas.config_manager import HeaderBarVisibility
@@ -58,9 +58,8 @@ class PreferencesDialog(Adw.PreferencesDialog):
                 return
             options[scheme_id] = name
 
-        # Exposing scheme names for translation here as those pulled out of the XML files don't
-        # seem to be getting applied. Undetermined whether that's a project issue this end or in
-        # piping elsewhere.
+        # Exposing scheme names for translation here as attempt to translate via scheme XML files
+        # wasn't fruitful
         preferenced_schemes = {
             # Translators: Description, a style name
             "iotas-mono": _("Monochrome"),
@@ -178,6 +177,7 @@ class PreferencesDialog(Adw.PreferencesDialog):
 
         self.__init_excessive_preferences_handling()
         self.__toast = None
+        self.__setup_temporary_combo_factories()
 
     def __build_actions(self) -> None:
         action_group = Gio.SimpleActionGroup.new()
@@ -401,3 +401,72 @@ class PreferencesDialog(Adw.PreferencesDialog):
         setting_maximum = iotas.config_manager.get_line_length_max()
         new_value = iotas.config_manager.get_default_line_length() if state else setting_maximum
         iotas.config_manager.set_line_length(new_value)
+
+    # Quick fix for this release (due to already being in string freeze) by using a combo row
+    # factory to accommodate for long strings not fitting in combo row popovers. This basically
+    # copies the stock Adw.ComboRow factory excluding the 20 character width limit.
+    def __setup_temporary_combo_factories(self) -> None:
+        header_combo_factory = Gtk.SignalListItemFactory()
+        header_combo_factory.connect("setup", self.__long_comborow_factory_setup)
+        header_combo_factory.connect(
+            "bind", self.__long_comborow_factory_bind, self._editor_header_bar_visibility_combo
+        )
+        header_combo_factory.connect(
+            "unbind", self.__long_comborow_factory_unbind, self._editor_header_bar_visibility_combo
+        )
+        self._editor_header_bar_visibility_combo.set_list_factory(header_combo_factory)
+
+        format_combo_factory = Gtk.SignalListItemFactory()
+        format_combo_factory.connect("setup", self.__long_comborow_factory_setup)
+        format_combo_factory.connect(
+            "bind", self.__long_comborow_factory_bind, self._editor_formatting_bar_visibility_combo
+        )
+        format_combo_factory.connect(
+            "unbind",
+            self.__long_comborow_factory_unbind,
+            self._editor_formatting_bar_visibility_combo,
+        )
+        self._editor_formatting_bar_visibility_combo.set_list_factory(format_combo_factory)
+
+    def __long_comborow_factory_setup(
+        self, _factory: Gtk.SignalListItemFactory, list_item: Gtk.ListItem
+    ) -> None:
+        box = Gtk.Box()
+
+        label = Gtk.Label()
+        label.set_xalign(0)
+        label.set_ellipsize(Pango.EllipsizeMode.END)
+        label.set_width_chars(1)
+        label.set_valign(Gtk.Align.CENTER)
+        box.append(label)
+
+        icon = Gtk.Image.new_from_icon_name("object-select-symbolic")
+        icon.set_accessible_role(Gtk.AccessibleRole.PRESENTATION)
+        box.append(icon)
+
+        list_item.set_child(box)
+
+    def __long_comborow_factory_bind(
+        self, _factory: Gtk.SignalListItemFactory, list_item: Gtk.ListItem, combo: Adw.ComboRow
+    ) -> None:
+        box = list_item.get_child()
+        label = box.get_first_child()
+        label.set_text(list_item.get_item().get_string())
+        combo.connect("notify::selected-item", self.__selected_item_changed, list_item)
+        self.__selected_item_changed(combo, None, list_item)
+
+    def __long_comborow_factory_unbind(
+        self, _factory: Gtk.SignalListItemFactory, _list_item: Gtk.ListItem, combo: Adw.ComboRow
+    ) -> None:
+        combo.disconnect_by_func(self.__selected_item_changed)
+
+    @staticmethod
+    def __selected_item_changed(
+        combo: Adw.ComboRow, _pspec: GObject.ParamSpec, list_item: Gtk.ListItem
+    ) -> None:
+        box = list_item.get_child()
+        icon = box.get_last_child()
+        if combo.get_selected_item() == list_item.get_item():
+            icon.set_opacity(1.0)
+        else:
+            icon.set_opacity(0.0)
