@@ -47,6 +47,8 @@ class SyncManager(GObject.Object):
         "finished": (GObject.SignalFlags.RUN_FIRST, None, (int,)),
         # Note: Note in conflict
         "note-conflict": (GObject.SignalFlags.RUN_FIRST, None, (Note,)),
+        # Note: Remotely deleted note
+        "note-deleted": (GObject.SignalFlags.RUN_FIRST, None, (Note,)),
         "secret-service-failure": (GObject.SignalFlags.RUN_FIRST, None, ()),
         # str: Previous category, str: Remote category
         "remote-category-sanitised": (GObject.SignalFlags.RUN_FIRST, None, (str, str)),
@@ -484,6 +486,7 @@ class SyncManager(GObject.Object):
         for remote_id in remote_del:
             note = self.__note_manager.fetch_note_by_remote_id(remote_id)
             if note is not None:
+                self.emit("note-deleted", note)
                 remove_notes.append(note)
                 self.__db.delete_note(note.id)
         if len(remove_notes) > 0:
