@@ -176,3 +176,14 @@ def have_window_with_width() -> bool:
     if not window:
         return False
     return window.get_width() > 0
+
+
+def check_for_open_first_result_shortcut(keyval: int, state: Gdk.ModifierType) -> bool:
+    """Check keyboard shortcut to activate first result has been pressed.
+
+    :param int keyval: The key value
+    :param Gdk.ModifierType state: Any modifier state
+    :return: Whether pressed
+    :rtype: bool
+    """
+    return keyval == Gdk.KEY_Return and state & Gdk.ModifierType.ALT_MASK
